==> haskell-retry-0.7.4.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.4.2
id: retry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
key: retry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
license: BSD3
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
author: Ozgun Ataman
exposed: True
exposed-modules:
    Control.Retry
abi: 18eab53b6ec4f30f3ecac4f0d5b0c94e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/retry-0.7.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/retry-0.7.4.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/retry-0.7.4.2
hs-libraries: HSretry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
depends:
    base-4.9.0.0 data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN ghc-prim-0.5.0.0
    random-1.1-54KmMHXjttlERYcr1mvsAe transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.7.4.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.4.2
id: retry-0.7.4.2-RgUAtfMVP2FCf8yGSEX72
key: retry-0.7.4.2-RgUAtfMVP2FCf8yGSEX72
license: BSD3
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
author: Ozgun Ataman
exposed: True
exposed-modules:
    Control.Retry
abi: 1cebaf6009e8cd189ca86fac599e80f1
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/retry-0.7.4.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/retry-0.7.4.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/retry-0.7.4.2
hs-libraries: HSretry-0.7.4.2-RgUAtfMVP2FCf8yGSEX72
depends:
    base-4.9.1.0 data-default-class-0.1.2.0-N42RtcTZUUAlapzICmPz4
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd ghc-prim-0.5.0.0
    random-1.1-9tceXaeYIMZ4JrKq20Egog transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
